@@ -16,6 +16,7 @@ OdbcConnection <- function(
   timezone = "UTC",
   encoding = "",
   bigint = c("integer64", "integer", "numeric", "character"),
+  timeout = Inf,
   driver = NULL,
   server = NULL,
   database = NULL,
@@ -31,7 +32,11 @@ OdbcConnection <- function(
 
   bigint <- bigint_mappings()[match.arg(bigint, names(bigint_mappings()))]
 
-  ptr <- odbc_connect(connection_string, timezone = timezone, encoding = encoding, bigint = bigint)
+  if (is.infinite(timeout)) {
+    timeout <- 0
+  }
+
+  ptr <- odbc_connect(connection_string, timezone = timezone, encoding = encoding, bigint = bigint, timeout = timeout)
   quote <- connection_quote(ptr)
 
   info <- connection_info(ptr)
@@ -155,15 +160,8 @@ setMethod(
     vapply(obj, odbcDataType, con = dbObj, FUN.VALUE = character(1), USE.NAMES = TRUE)
   })
 
-#' @rdname OdbcConnection
-#' @inheritParams DBI::dbQuoteString
-#' @export
-setMethod(
-  "dbQuoteString", c("OdbcConnection", "character"),
-  function(conn, x, ...) {
-    # Optional
-    getMethod("dbQuoteString", c("DBIConnection", "character"), asNamespace("DBI"))(conn, x, ...)
-  })
+#' @rawNamespace exportMethods(dbQuoteString)
+NULL
 
 #' @rdname OdbcConnection
 #' @inheritParams DBI::dbQuoteIdentifier
@@ -183,48 +181,35 @@ setMethod(
     DBI::SQL(paste(conn@quote, encodeString(x), conn@quote, sep = ""))
   })
 
-
-#' Un-Quote identifiers
-#'
-#' Call this method to generate a string that is unquoted. This is the inverse
-#' of `DBI::dbQuoteIdentifier`.
-#'
-#' @param x A character vector to un-quote.
-#' @inheritParams DBI::dbQuoteIdentifier
-#' @export
-setGeneric(
-  "dbUnQuoteIdentifier",
-  function(conn, x, ...) standardGeneric("dbUnQuoteIdentifier")
-)
-
-#' @rdname dbUnQuoteIdentifier
-#' @inheritParams DBI::dbQuoteIdentifier
-#' @export
-setMethod(
-  "dbUnQuoteIdentifier", c("OdbcConnection", "SQL"),
-  function(conn, x) {
-    x <- as.character(x)
-    x <- gsub(paste0("^", conn@quote), "", x)
-    x <- gsub(paste0(conn@quote, "$"), "", x)
-    x
-  })
-
-#' @rdname dbUnQuoteIdentifier
-#' @inheritParams DBI::dbQuoteIdentifier
-#' @export
-setMethod(
-  "dbUnQuoteIdentifier", c("OdbcConnection", "character"),
-  function(conn, x) {
-    x
-  })
-
 #' @rdname OdbcConnection
-#' @inheritParams DBI::dbListTables
+#' @inheritParams DBI::dbQuoteIdentifier
+#' @export
+setMethod(
+  "dbQuoteIdentifier", c("OdbcConnection", "SQL"),
+  getMethod("dbQuoteIdentifier", c("DBIConnection", "SQL"), asNamespace("DBI")))
+
+#' @inherit DBI::dbListTables
+#' @param catalog_name The name of the catalog to return, the default returns all catalogs.
+#' @param schema_name The name of the schema to return, the default returns all schemas.
+#' @param table_name The name of the table to return, the default returns all tables.
+#' @param table_type The type of the table to return, the default returns all table types.
+#' @aliases dbListTables
+#' @details
+#' \code{\%} can be used as a wildcard in any of the search parameters to
+#'   match 0 or more characters. `_` can be used to match any single character.
+#' @seealso The ODBC documentation on [Pattern Value Arguments](https://docs.microsoft.com/en-us/sql/odbc/reference/develop-app/pattern-value-arguments)
+#'   for further details on the supported syntax.
 #' @export
 setMethod(
   "dbListTables", "OdbcConnection",
-  function(conn, ...) {
-    connection_sql_tables(conn@ptr, ...)$table_name
+  function(conn, catalog_name = NULL, schema_name = NULL, table_name = NULL,
+    table_type = NULL, ...) {
+
+    connection_sql_tables(conn@ptr,
+      catalog_name = catalog_name,
+      schema_name = schema_name,
+      table_name = table_name,
+      table_type = table_type)$table_name
   })
 
 #' @rdname OdbcConnection
@@ -234,16 +219,24 @@ setMethod(
   "dbExistsTable", c("OdbcConnection", "character"),
   function(conn, name, ...) {
     stopifnot(length(name) == 1)
-    dbUnQuoteIdentifier(conn, name) %in% dbListTables(conn, ...)
+    name %in% dbListTables(conn, ...)
   })
 
-#' @rdname OdbcConnection
+#' @inherit DBI::dbListFields
 #' @inheritParams DBI::dbListFields
+#' @aliases dbListFields
+#' @inheritParams dbListTables,OdbcConnection-method
+#' @param column_name The name of the column to return, the default returns all columns.
+#' @inherit dbListTables,OdbcConnection-method details
 #' @export
 setMethod(
   "dbListFields", c("OdbcConnection", "character"),
-  function(conn, name, ...) {
-    connection_sql_columns(conn@ptr, table_name = name)[["name"]]
+  function(conn, name, catalog_name = NULL, schema_name = NULL, column_name = NULL, ...) {
+    connection_sql_columns(conn@ptr,
+      table_name = name,
+      catalog_name = catalog_name,
+      schema_name = schema_name,
+      column_name = column_name)[["name"]]
   })
 
 #' @rdname OdbcConnection
